<?php

if ( ! defined( 'ABSPATH' ) ) { exit; }

if ( ! class_exists( 'PWLE_Output_CSV' ) ) :

class PWLE_Output_CSV extends PWLE_Output {

    public $output_filename;

    private $csv_file;

    function __construct() {
        $this->name = 'CSV';
        $this->title = 'Export to CSV';
        $this->icon = 'fa-file-text-o';
        $this->color = '#EA5C00';
        $this->extension = '.csv';
    }

    function add_row( $input_class, $row ) {
        if ( !isset( $this->csv_file ) ) {
            $this->csv_file = fopen( $this->output_filename, 'w' );
        }

        foreach( $row as &$value ) {
            $value = trim( preg_replace( '/\s+/', ' ', $value ) );
        }

        fputcsv( $this->csv_file, $row );
    }

    function finish() {
        if ( isset( $this->csv_file ) ) {
            fclose( $this->csv_file );
        }
    }

    function send_file() {
        if ( file_exists( $this->output_filename ) ) {

            header( 'Content-Type: application/octet-stream' );
            header( 'Content-Disposition: attachment; filename="' . $this->get_filename() . '"' );
            header( 'Content-Description: File Transfer' );
            header( 'Expires: 0' );
            header( 'Cache-Control: must-revalidate' );
            header( 'Pragma: public' );
            header( 'Content-Length: ' . filesize( $this->output_filename ) );
            readfile( $this->output_filename );
            unlink( $this->output_filename );
            exit;

        } else {
            wp_die( "Temporary file not found ({$this->output_filename})." );
        }
    }
}

global $pw_lets_export;
$pw_lets_export->output_classes[] = new PWLE_Output_CSV();

endif;

?>